@@ -3,6 +3,7 @@
 DOM Level 2 CSS CSSValue, CSSPrimitiveValue and CSSValueList are **no longer**
 supported and are replaced by these new classes.
 """
+
 __all__ = [
     'PropertyValue',
     'Value',
@@ -45,7 +46,7 @@ class PropertyValue(cssutils.util._NewBase):
         :param readonly:
             defaults to False
         """
-        super(PropertyValue, self).__init__()
+        super().__init__()
 
         self.parent = parent
         self.wellformed = False
@@ -68,11 +69,10 @@ class PropertyValue(cssutils.util._NewBase):
 
     def __iter__(self):
         "Generator which iterates over values."
-        for item in self.__items():
-            yield item
+        yield from self.__items()
 
     def __repr__(self):
-        return "cssutils.css.%s(%r)" % (self.__class__.__name__, self.cssText)
+        return f"cssutils.css.{self.__class__.__name__}({self.cssText!r})"
 
     def __str__(self):
         return "<cssutils.css.%s object length=%r cssText=%r at " "0x%x>" % (
@@ -246,7 +246,7 @@ class Value(cssutils.util._NewBase):
     _value = ''
 
     def __init__(self, cssText=None, parent=None, readonly=False):
-        super(Value, self).__init__()
+        super().__init__()
 
         self.parent = parent
         self.wellformed = False
@@ -255,15 +255,17 @@ class Value(cssutils.util._NewBase):
             self.cssText = cssText
 
     def __repr__(self):
-        return "cssutils.css.%s(%r)" % (self.__class__.__name__, self.cssText)
+        return f"cssutils.css.{self.__class__.__name__}({self.cssText!r})"
 
     def __str__(self):
-        return "<cssutils.css.%s object type=%s value=%r cssText=%r at 0x%x>" % (
-            self.__class__.__name__,
-            self.type,
-            self.value,
-            self.cssText,
-            id(self),
+        return (
+            "<cssutils.css.{} object type={} value={!r} cssText={!r} at 0x{:x}>".format(
+                self.__class__.__name__,
+                self.type,
+                self.value,
+                self.cssText,
+                id(self),
+            )
         )
 
     def _setCssText(self, cssText):
@@ -290,12 +292,14 @@ class Value(cssutils.util._NewBase):
         doc='String value of this value.',
     )
 
-    type = property(
-        lambda self: self._type,  # _setType,
-        doc="Type of this value, for now the production type "
-        "like e.g. `DIMENSION` or `STRING`. All types are "
-        "defined as constants in :class:`~cssutils.css.Value`.",
-    )
+    @property
+    def type(self):
+        """
+        Type of this value, for now the production type
+        like e.g. `DIMENSION` or `STRING`. All types are
+        defined as constants in :class:`~cssutils.css.Value`.
+        """
+        return self._type
 
     def _setValue(self, value):
         # TODO: check!
@@ -492,9 +496,10 @@ class ColorValue(Value):
         doc='Same as cssText but without comments.',
     )
 
-    type = property(
-        lambda self: Value.COLOR_VALUE, doc="Type is fixed to Value.COLOR_VALUE."
-    )
+    @property
+    def type(self):
+        """Type is fixed to Value.COLOR_VALUE."""
+        return Value.COLOR_VALUE
 
     def _getName(self):
         for n, v in list(self.COLORS.items()):
@@ -511,15 +516,21 @@ class ColorValue(Value):
     )
 
     red = property(lambda self: self._red, doc='red part as integer between 0 and 255')
-    green = property(
-        lambda self: self._green, doc='green part as integer between 0 and 255'
-    )
-    blue = property(
-        lambda self: self._blue, doc='blue part as integer between 0 and 255'
-    )
-    alpha = property(
-        lambda self: self._alpha, doc='alpha part as float between 0.0 and 1.0'
-    )
+
+    @property
+    def green(self):
+        """green part as integer between 0 and 255"""
+        return self._green
+
+    @property
+    def blue(self):
+        """blue part as integer between 0 and 255"""
+        return self._blue
+
+    @property
+    def alpha(self):
+        """alpha part as float between 0.0 and 1.0"""
+        return self._alpha
 
 
 class DimensionValue(Value):
@@ -599,7 +610,7 @@ class URIValue(Value):
     _uri = Value._value
 
     def __str__(self):
-        return "<cssutils.css.%s object type=%s value=%r uri=%r cssText=%r at 0x%x>" % (
+        return "<cssutils.css.{} object type={} value={!r} uri={!r} cssText={!r} at 0x{:x}>".format(
             self.__class__.__name__,
             self.type,
             self.value,
@@ -764,7 +775,7 @@ class MSValue(CSSFunction):
         return funcProds
 
     def _setCssText(self, cssText):
-        super(MSValue, self)._setCssText(cssText)
+        super()._setCssText(cssText)
 
     cssText = property(
         lambda self: cssutils.ser.do_css_MSValue(self),
@@ -783,7 +794,9 @@ class CSSCalc(CSSFunction):
     _functionName = 'CSSCalc'
 
     def __str__(self):
-        return "<cssutils.css.%s object at 0x%x>" % (self.__class__.__name__, id(self))
+        return "<cssutils.css.{} object at 0x{:x}>".format(
+            self.__class__.__name__, id(self)
+        )
 
     def _setCssText(self, cssText):
         self._checkReadonly()
@@ -820,7 +833,9 @@ class CSSCalc(CSSFunction):
             ),
         )
 
-        _operant = lambda: Choice(_DimensionProd(self), _CSSVariableProd(self))  # noqa
+        _operant = lambda: Choice(  # noqa:E731
+            _DimensionProd(self), _CalcValueProd(self), _CSSVariableProd(self)
+        )
 
         prods = Sequence(
             Prod(
@@ -862,7 +877,7 @@ class CSSVariable(CSSFunction):
     _fallback = None
 
     def __str__(self):
-        return "<cssutils.css.%s object name=%r value=%r at 0x%x>" % (
+        return "<cssutils.css.{} object name={!r} value={!r} at 0x{:x}>".format(
             self.__class__.__name__,
             self.name,
             self.value,
@@ -923,9 +938,10 @@ class CSSVariable(CSSFunction):
         ":class:`cssutils.css.CSSVariablesDeclaration`.",
     )
 
-    fallback = property(
-        lambda self: self._fallback, doc="The fallback Value of this variable"
-    )
+    @property
+    def fallback(self):
+        """The fallback Value of this variable"""
+        return self._fallback
 
     type = property(lambda self: Value.VARIABLE, doc="Type is fixed to Value.VARIABLE.")
 
